package db

import (
	"applet/app/db/model"
	"applet/app/utils/logx"
	"errors"
	"xorm.io/xorm"
)

type CentralKitchenWxTransferOrd struct {
	Db         *xorm.Engine `json:"db"`
	OutTradeNo string       `json:"out_trade_no"`
}

func (centralKitchenWxTransferOrdDb *CentralKitchenWxTransferOrd) Set(outTradeNo string) { // set方法
	centralKitchenWxTransferOrdDb.Db = Db
	centralKitchenWxTransferOrdDb.OutTradeNo = outTradeNo
}

type FindCentralKitchenWxTransferOrd struct {
	model.CentralKitchenWxTransferOrdList `xorm:"extends"`
	model.User                            `xorm:"extends"`
}

func (FindCentralKitchenWxTransferOrd) TableName() string {
	return "central_kitchen_wx_transfer_ord_list"
}

type GetCentralKitchenWxTransferOrdResp struct {
	Ord  *model.CentralKitchenWxTransferOrd `json:"ord"`
	List []*FindCentralKitchenWxTransferOrd `json:"list"`
}

func (centralKitchenWxTransferOrdDb *CentralKitchenWxTransferOrd) GetCentralKitchenWxTransferOrd() (resp GetCentralKitchenWxTransferOrdResp, err error) {
	//1、查找 central_kitchen_wx_transfer_ord
	m := new(model.CentralKitchenWxTransferOrd)
	has, err := centralKitchenWxTransferOrdDb.Db.Where("out_trade_no =?", centralKitchenWxTransferOrdDb.OutTradeNo).Get(m)
	if err != nil {
		return resp, logx.Error(err)
	}
	if has == false {
		return resp, errors.New("未查询到相关转账记录")
	}
	resp.Ord = m

	//1、查找 central_kitchen_wx_transfer_ord_list 记录
	var list []*FindCentralKitchenWxTransferOrd
	err = centralKitchenWxTransferOrdDb.Db.Where("out_trade_no =?", centralKitchenWxTransferOrdDb.OutTradeNo).
		Join("LEFT", "user", "user.id = central_kitchen_wx_transfer_ord_list.uid").
		Find(&list)
	if err != nil {
		return resp, err
	}
	resp.List = list
	return
}

func (centralKitchenWxTransferOrdDb *CentralKitchenWxTransferOrd) FindCentralKitchenWxTransferOrd(page, limit int) (list []*model.CentralKitchenWxTransferOrd, total int64, err error) {
	total, err = centralKitchenWxTransferOrdDb.Db.Limit(limit, (page-1)*limit).FindAndCount(&list)
	if err != nil {
		return nil, 0, err
	}
	return
}

func (centralKitchenWxTransferOrdDb *CentralKitchenWxTransferOrd) CentralKitchenWxTransferOrdInsert(m *model.CentralKitchenWxTransferOrd) (int, error) {
	_, err := centralKitchenWxTransferOrdDb.Db.InsertOne(m)
	if err != nil {
		return 0, err
	}
	return m.Id, nil
}

func (centralKitchenWxTransferOrdDb *CentralKitchenWxTransferOrd) CentralKitchenWxTransferOrdInsertBySession(session *xorm.Session, m *model.CentralKitchenWxTransferOrd) (int, error) {
	_, err := session.InsertOne(m)
	if err != nil {
		return 0, err
	}
	return m.Id, nil
}

func (centralKitchenWxTransferOrdDb *CentralKitchenWxTransferOrd) CentralKitchenWxTransferOrdUpdate(m *model.CentralKitchenWxTransferOrd, forceColums ...string) (int64, error) {
	var (
		affected int64
		err      error
	)
	if forceColums != nil {
		affected, err = centralKitchenWxTransferOrdDb.Db.Where("out_trade_no=?", centralKitchenWxTransferOrdDb.OutTradeNo).Cols(forceColums...).Update(m)
	} else {
		affected, err = centralKitchenWxTransferOrdDb.Db.Where("out_trade_no=?", centralKitchenWxTransferOrdDb.OutTradeNo).Update(m)
	}
	if err != nil {
		return 0, err
	}
	return affected, nil
}
